@@ -10,8 +10,8 @@ from je_api_testka.utils.json.json_format.json_process import reformat_json
 # xml
 from je_api_testka.utils.xml.xml_file.xml_file import XMLParser
 from je_api_testka.utils.xml.xml_file.xml_file import reformat_xml_file
-from je_api_testka.utils.xml.xml_file.xml_file import elements_tree_to_dict
-from je_api_testka.utils.xml.xml_file.xml_file import dict_to_elements_tree
+from je_api_testka.utils.xml.change_xml_structure.change_xml_structure import elements_tree_to_dict
+from je_api_testka.utils.xml.change_xml_structure.change_xml_structure import dict_to_elements_tree
 # test_record
 from je_api_testka.utils.test_record.record_test_result_class import test_record
 # html_output
